/*
*   Data sent from CasparCG Client as templateData
*   is pushed into corresponding HTML id element
*
*   Usage:
*   insert a script reference in the HTML template header.
*   ex: <script type="text/javascript" src="CasparCG.js"></script>
*   Make sure that the id that you refer to is the innermost tag.
*   Everything within that tag id will be replaced by the value sent from CasparCG
*
*   put together by Tomas Linden
*   modified by Øjvind Søgaard Andersen
*
   Structure of data sent from CasparCG:
   <templateData>
      <componentData id="#idCaspar#">
         <data id="text" value="#valCaspar#" />
      </componentData>
      :
      :
      <componentData id="#idCaspar#">
         <data id="text" value="#valCaspar#" />
      </componentData>
   </templateData>
*/
// Global variable for data from CasparCG
var dataCaspar = {};

// Replace characters that could become a problem if left as is
function escapeHtml(unsafe) {
  return unsafe.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/"/g, "&quot;").replace(/'/g, "&#039;");
}

// Parse templateData into an XML object
function parseCaspar(str) {
  var xmlDoc;
  if (window.DOMParser) {
    parser = new DOMParser();
    xmlDoc = parser.parseFromString(str, "text/xml");
  }
  dataCaspar = XML2JSON(xmlDoc.documentElement.childNodes);
	
}


// Make the XML templateData message into a more simple key:value object
function XML2JSON(node) {
  var data = {}; // resulting object
  for (k = 0; k < node.length; k++) {
    var idCaspar = node[k].getAttribute("id");
    var valCaspar = node[k].childNodes[0].getAttribute("value");
    if (idCaspar != undefined && valCaspar != undefined) {
      data[idCaspar] = valCaspar;
    };
  }
  return data;
	
}

// Main function to insert data
function dataInsert(dataCaspar) {
  for (var idCaspar in dataCaspar) {
    var idTemplate = document.getElementById(idCaspar);
    if (idTemplate != undefined) {
      idTemplate.innerHTML = escapeHtml(dataCaspar[idCaspar]);
    }
  }
	
}

// Call for a update of data from CasparCG client
function update(str) {
  parseCaspar(str); // Parse templateData into an XML object
  dataInsert(dataCaspar); // Insert data
  logos(dataCaspar); // Insert logos
  colors(dataCaspar);  // Insert colors
  }

// insert data from CasparCg client when activated
function play(str) {
	
  parseCaspar(str); // Parse templateData into an XML object
  dataInsert(dataCaspar); // Insert data
	
}

// Call for a next from CasparCG client
function next() {
  //gwd.actions.timeline.play('document.body');
}

// Call for a stop from CasparCG client
function stopTemplate () {
	
	
}
function stop() {
	//document.getElementById("bugwrapper").className = "bug-off";
	document.getElementById("matchup").className = "matchup-off";
	document.getElementById("body").className = "removeBG";
	//var summaryCheck = document.getElementById("summary")
	//if (summaryCheck.classList.contains('summary-on')){
	//document.getElementById("bugwrapper").style.opacity = "0";
	//document.getElementById("summary").className = "summary-off";
//}
	
	//var l3rdCheck = document.getElementById("l3rd")
	//if (l3rdCheck.classList.contains('l3rd-on')){
	//document.getElementById("l3rd").className = "l3rd-off";
//}
	setTimeout(window.remove, 1000);
}

function invoke(str) {
	parseCaspar(str); // Parse templateData into an XML object
  	dataInsert(dataCaspar); // Insert data

	
	if (str = "addMatchup") {
		addMatchup(dataCaspar); // add matchup
		
	}
	
	if (str = "removeMatchup") {
		removeMatchup(dataCaspar); // remove matchup
		
	}
	
	if (str="removeBG") {
		removeBG(dataCaspar); // clear background image
	}
	
	if (str="addBG") {
		addBG(dataCaspar); // add background image)
	}
	
	if (str="halftime") {
		halftime(dataCaspar); // switch to halftime graphic)
	}

}

// Add team logos 
        function logos(dataCaspar) {
		
			if (dataCaspar.hasOwnProperty("t1logo"))
				{

					document.getElementById("t1matchuplogo").src = escapeHtml(dataCaspar["t1logo"]);
				}
			
			if (dataCaspar.hasOwnProperty("t2logo"))
				{		

					document.getElementById("t2matchuplogo").src = escapeHtml(dataCaspar["t2logo"]) ;
				}

			
			if (dataCaspar.hasOwnProperty("broadcastlogo"))
			{
				document.getElementById("broadcastlogo").src = escapeHtml(dataCaspar["broadcastlogo"]) ;
				
			}
	
			
		}



// add colors
		function colors(dataCaspar) {
			
			
			if (dataCaspar.hasOwnProperty("t1color1"))
				{

					document.getElementById("t1matchupcolor").style.backgroundColor = escapeHtml(dataCaspar["t1color1"]);
					
				}
			
			if (dataCaspar.hasOwnProperty("t2color1"))
			{
				document.getElementById("t2matchupcolor").style.backgroundColor = escapeHtml(dataCaspar["t2color1"]);

		}


		}

// add matchup
		function addMatchup(str) {
		parseCaspar(str); // Parse templateData into an XML object
  		dataInsert(dataCaspar); // Insert data
		document.getElementById("matchup").className = "matchup-on";
		}

// remove matchup
		function removeMatchup(dataCaspar) {
		document.getElementById("matchup").className = "matchup-off";
			
		}
		
// add background image
		function addBG(str) {
		document.getElementById("body").className = "addBG";
			
		}
// remove background image
		function removeBG(str) {
		document.getElementById("body").className = "removeBG";
			
		}
		
// add halftime scores
		function halftime(str) {
		document.getElementById("t1matchupdetails").className = "t1halftimedetails";
		document.getElementById("t2matchupdetails").className = "t2halftimedetails";	
		//var t1halfscore = document.getElementById('t1matchupdetails');
		//t1halfscore.classList.toggle('t1halftimedetails');
		//var t2halfscore = document.getElementById('t2matchupdetails');
		//t2halfscore.classList.toggle('t2halftimedetails');
		}
